#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-textual
version:              0.3.0.3
visibility:           public
id:                   data-textual-0.3.0.3-1OPBoy3G6MtKry9r3rHcwO
key:                  data-textual-0.3.0.3-1OPBoy3G6MtKry9r3rHcwO
license:              BSD-3-Clause
copyright:            2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-textual
synopsis:             Human-friendly textual representations.
description:
    This package provides an interface for converting between data and its
    (human-friendly) textual representation.

category:             Data, Text
abi:                  920f6fa3537d83e7c8e931cebc7e3681
exposed:              True
exposed-modules:
    Data.Textual Data.Textual.Fractional Data.Textual.Integral

import-dirs:          /usr/lib/ghc-9.6.6/site-local/data-textual-0.3.0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/data-textual-0.3.0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/data-textual-0.3.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-textual
hs-libraries:         HSdata-textual-0.3.0.3-1OPBoy3G6MtKry9r3rHcwO
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    parsers-0.12.12-DITnP6X1XI58dGVYmGX0ES text-2.0.2
    text-latin1-0.3.1-InNlHkX7Sgc4slt2qb10SP
    text-printer-0.5.0.2-458JMKpQ2Lz6Va24cZxWkD

haddock-interfaces:
    /usr/share/doc/haskell-data-textual/html/data-textual.haddock

haddock-html:         /usr/share/doc/haskell-data-textual/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

